##  Creating a New Fact Sheet
You create a new fact sheet in the inventory by clicking the New Fact Sheet button at the top. Select the fact sheet type and subtype, provide a name, and then click Create.
![Creating a New Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio90a110fd212744c59a1dea458b964447_LowRes.png)
Creating a New Fact Sheet
It is best to enable the Enhanced Fact Sheet Creation  option in the admin area. This new fact sheet creation form allows admins to enforce that fact sheet creators assign a subscriber before they can finish creating the fact sheet. For a detailed guide, see[Creating a Fact Sheet in the Inventory](https://help.sap.com/docs/leanix/ea/creating-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759925e7a441014a7e9e6f502b4cd21__creating_a_fact_sheet_in_the_inventory).
